// $Author$
// $DateTime$
// $File$
// $Revision$
//
// Copyright 2005-2006 Cognos, Inc.
package processors

import com.cognos.mobile.server.core.SCResponse
import com.cognos.mobile.server.handler.admin.XMLRenderer
import com.cognos.mobile.server.handler.admin.SessionRequestProcessor
import com.cognos.mobile.common.C8.PortalItem;
import com.cognos.mobile.common.CMException;
import com.cognos.mobile.common.CMErrors;
import com.cognos.mobile.vm.VM
import com.cognos.mobile.server.core.SCReportManager
import com.cognos.mobile.server.core.ReportRenderer
import com.cognos.mobile.server.core.InboxRenderer
import com.cognos.mobile.common.CMStringHelper2
import com.cognos.mobile.common.CMIntSet
import com.cognos.mobile.database.DBHistoryLogger
import com.cognos.mobile.database.ResourceObject
import com.cognos.mobile.common.IHistoryLogger
import groovy.xml.MarkupBuilder
import org.dom4j.Element;

def renderInbox = { c8config, session, database, userId ->
	def writer = new StringWriter()
	def xml = new MarkupBuilder(writer)
	def db = database.getDashboard(session.userId)
	def favs = database.listFavourites(session.userId);

	def values = database.browseRenders(session.userId, true)

	xml.home(userId:"$session.userId", userName: "$session.userName", displayName: "$session.displayName", admin: "$session.administrator"){
		values.each{ rr -> 
		def thumbnail;
		if ( rr.status == 2 ) thumbnail = env["SCRIPT_NAME"] + "/mobileService/renders/${rr.renderID}/pages/1/thumb.png";
		else thumbnail = "images/icon_error_report.png";
		render( status: rr.status, renderTime: CMStringHelper2.formatDateTime(rr.renderTime), sourcePath: rr.sourcePath, label: rr.label, id: rr.renderID, img: thumbnail, sourceCode:rr.sourceCode, isViewed:rr.isViewed)}
		if (db != null){
			dashboard(status: db.status, renderTime:CMStringHelper2.formatDateTime(db.renderTime), sourcePath: db.sourcePath, label: db.label, id: db.renderID, resourceID: db.resourceID,img: env["SCRIPT_NAME"] + "/mobileService/renders/${db.renderID}/pages/1/dashboard.png",sourceCode:db.sourceCode)
		}
		if (favs != null && favs.length > 0 ){
			favourites {
				favs.each{
					fav(resourceId: it.resourceID, label: it.label, storeId: it.identifier, sourcePath: it.sourcePath, cmPath: it.cmPath, desc: it.description )
				}
			}
		}
	}
	return writer.toString()
}

def m = ( path =~ /\/user\/(\d+)?\/?(.*)$/)
def userId = session.userId
path = m[0][2]

switch( path ){
	case ~/namespace$/:
		XMLRenderer renderer = [database, request]
		Element el = renderer.renderSession(session)
		String[] ns = SessionRequestProcessor.getNamespacesForSession( session, request )
		VM.log( getClass(), VM.SEVERITY_DEBUG, "" + ns )
		ns.each{ _ns -> el.add( renderer.renderNamespace( _ns ))}
		return el 
	case ~/home$/ :
		return renderInbox(c8config, session, database, userId)
	case ~/inbox\/\d+/ :
		def renderId = Integer.valueOf(args["renderId"])
		switch( method ){
			case "delete":
				SCReportManager manager = new SCReportManager(isf, database, c8config, tmp)
				def db = database.getDashboard(session.userId);
				if( db != null && db.renderID == renderId ) manager.removeDashboard(session.userId, renderId)
				def render = manager.describeRender(renderId)
				def renders = database.browseRenders(session.userId, false);
				renders.each{
					if( it.sourcePath.equals(render.sourcePath)) manager.deleteRender(it.renderID, session.userId)
				}
				
				return renderInbox(c8config, session, database, session.userId)
		}
		break
	case ~/fav\/.*/ :
		def p = args["storeId"]
		def storeId, sourcePath, reportPath
		storeId == null
		sourcePath == null
		reportPath == null
		if( p.startsWith("storeID(")) storeId = p.substring( 9, p.length() -  2)
		else if( p.startsWith("store:" )) storeId = p.substring( 6, p.length())
		else if( p.startsWith("source:" )) sourcePath = p.substring( 7, p.length())
		else if( p.startsWith("cm:" )) reportPath = p.substring( 3, p.length())
		ResourceObject[] favourites = database.listFavourites(session.userId)
		def item
		def ro
		try {
			item = session.c8PortalTree.findItem(storeId, reportPath, sourcePath)
			ro = favourites.find{ it.cmPath == item.cmPath }
		} catch (CMException cme) {
			item = null
			if (storeId != null) ro = favourites.find{ it.storeId == storeId }
			if( ( ro == null ) && ( sourcePath != null ) ) ro = favourites.find{ it.sourcePath == sourcePath }
			if( ( ro == null ) && ( reportPath != null ) ) ro = favourites.find{ it.reportPath == reportPath }
		}
		switch( method ){
			case "delete":
				if( ro != null ) database.deleteFavourite( session.userId, ro )
				return renderInbox(c8config, session, database, session.userId)
			default: // ie, PUT, GET
				if( item == null ) {
					String details = "unable to retrieve C8 portal item" + ( ( storeId != null ) ? " - " + storeId : "" ) + ( ( reportPath != null ) ? " - " + reportPath : "" ) + ( ( sourcePath != null ) ? " - " + sourcePath : "" );
					VM.log(this.class, VM.SEVERITY_ERROR, details);
					throw new CMException(CMErrors.SERVER_BAD_REPORT_PATH, details)
				}
				if ( ro == null ) database.addFavourite(session.userId, item)
				return renderInbox(c8config, session, database, session.userId)
		}
		break
		
	case ~/dashboard\/\d+/ :
		def renderId = Integer.valueOf(args["renderId"])
		switch( method ){
			case "delete":
				SCReportManager manager = new SCReportManager(isf, database, c8config, tmp)
				manager.removeDashboard(session.userId, renderId)
				return renderInbox(c8config, session, database, session.userId)
			case "put":
				SCReportManager manager = new SCReportManager(isf, database, c8config, tmp)
				manager.setDashboard(session.userId, renderId)
				return renderInbox(c8config, session, database, session.userId)
		}
		break	
	case ~/inbox\/.*/:
		def p = args["type"]
		def reportPath = args["id"];
		
		SCReportManager manager = new SCReportManager(isf, database, c8config, tmp)
		def renders = database.browseRenders(session.userId)

		if( p.startsWith("source:" )){
			renders.each{ rr ->
				if( rr.sourcePath.equals(reportPath)) manager.deleteRender(rr.renderID, session.userId)
			}
		} else if( p.startsWith("cm:" )){
			renders.each{ rr ->
				if( rr.cmPath.equals(reportPath)) manager.deleteRender(rr.renderID, session.userId)
			}
		}
		return renderInbox(c8config, session, database, session.userId)
	case ~/inbox$/:
		switch( method ){
			case "delete":
				SCReportManager manager = new SCReportManager(isf, database, c8config, tmp)
				def db = database.getDashboard(session.userId);
				database.browseRenders(session.userId).each{ rr ->
					if( db != null && db.renderID == rr.renderID ) manager.removeDashboard(session.userId, renderId)
					database.deleteRender(rr.renderID, session.userId)
				}
				return renderInbox(c8config, session, database, session.userId)
			default: // ie, GET
				return renderInbox(c8config, session, database, session.userId)
		}
}
return null

